==> dde-session-shell_5.5.50.orig.tar.xz: dde-session-shell-5.5.50/translations/dde-session-shell_pl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl">
<context>
    <name>AuthFace</name>
    <message>
        <source>Face ID</source>
        <translation>ID Twarzy</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Weryfikacja zakończona pomyślnie</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Weryfikacja nie powiodła się, pozostała %n próba</numerusform><numerusform>Weryfikacja nie powiodła się, pozostały %n próby</numerusform><numerusform>Weryfikacja nie powiodła się, pozostało %n prób </numerusform><numerusform>Weryfikacja nie powiodła się, pozostało %n prób </numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Weryfikacja nie powiodła się, pozostała tylko jedna szansa </translation>
    </message>
    <message>
        <source>Verify your Face ID</source>
        <translation>Zweryfikuj swoje ID Twarzy</translation>
    </message>
    <message>
        <source>Face ID locked, use password please</source>
        <translation>ID Twarzy zablokowane, proszę użyć hasła</translation>
    </message>
    <message>
        <source>Device unavailable!</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AuthFingerprint</name>
    <message>
        <source>Verify your fingerprint</source>
        <translation>Zweryfikuj odcisk palca </translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Weryfikacja zakończona pomyślnie</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Weryfikacja nie powiodła się, pozostała %n próba </numerusform><numerusform>Weryfikacja nie powiodła się, pozostały %n próby </numerusform><numerusform>Weryfikacja nie powiodła się, pozostało %n prób </numerusform><numerusform>Weryfikacja nie powiodła się, pozostało %n prób </numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Weryfikacja nie powiodła się, pozostała tylko jedna szansa </translation>
    </message>
    <message>
        <source>Fingerprint locked, use password please</source>
        <translation>Odcisk palca zablokowany, użyj hasła</translation>
    </message>
</context>
<context>
    <name>AuthIris</name>
    <message>
        <source>Iris ID</source>
        <translation>ID Tęczówki</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Weryfikacja zakończona pomyślnie</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Weryfikacja nie powiodła się, pozostała %n próba</numerusform><numerusform>Weryfikacja nie powiodła się, pozostały %n próby</numerusform><numerusform>Weryfikacja nie powiodła się, pozostało %n prób </numerusform><numerusform>Weryfikacja nie powiodła się, pozostało %n prób </numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Weryfikacja nie powiodła się, pozostała tylko jedna szansa </translation>
    </message>
    <message>
        <source>Verify your Iris ID</source>
        <translation>Zweryfikuj swoje ID Tęczówki</translation>
    </message>
    <message>
        <source>Iris ID locked, use password please</source>
        <translation>ID Tęczówki zablokowane, proszę użyć hasła</translation>
    </message>
</context>
<context>
    <name>AuthPassword</name>
    <message>
        <source>Verification successful</source>
        <translation>Weryfikacja zakończona pomyślnie</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Weryfikacja nie powiodła się, pozostała %n próba</numerusform><numerusform>Weryfikacja nie powiodła się, pozostały %n próby</numerusform><numerusform>Weryfikacja nie powiodła się, pozostało %n prób </numerusform><numerusform>Weryfikacja nie powiodła się, pozostało %n prób </numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Weryfikacja nie powiodła się, pozostała tylko jedna szansa </translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Nieprawidłowe hasło</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Hasło</translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Spróbuj ponownie za 1 minutę</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Spróbuj ponownie za %n minute</numerusform><numerusform>Spróbuj ponownie za %n minuty</numerusform><numerusform>Spróbuj ponownie za %n minut</numerusform><numerusform>Spróbuj ponownie za %n minut</numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Zresetuj hasło</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>Zapomniałeś hasła?</translation>
    </message>
</context>
<context>
    <name>AuthSingle</name>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Spróbuj ponownie za 1 minutę</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Spróbuj ponownie za %n minute</numerusform><numerusform>Spróbuj ponownie za %n minuty</numerusform><numerusform>Spróbuj ponownie za %n minut</numerusform><numerusform>Spróbuj ponownie za %n minut</numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Zresetuj hasło</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>Zapomniałeś hasła?</translation>
    </message>
</context>
<context>
    <name>AuthUKey</name>
    <message>
        <source>Verification successful</source>
        <translation>Weryfikacja zakończona pomyślnie</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Weryfikacja nie powiodła się, pozostała %n próba</numerusform><numerusform>Weryfikacja nie powiodła się, pozostały %n próby</numerusform><numerusform>Weryfikacja nie powiodła się, pozostało %n prób</numerusform><numerusform>Weryfikacja nie powiodła się, pozostało %n prób</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Weryfikacja nie powiodła się, pozostała tylko jedna szansa </translation>
    </message>
    <message>
        <source>Wrong PIN</source>
        <translation>Nieprawidłowy PIN</translation>
    </message>
    <message>
        <source>UKey is required</source>
        <translation>UKey jest wymagany</translation>
    </message>
    <message>
        <source>Enter your PIN</source>
        <translation>Wpisz swój PIN</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>Spróbuj ponownie za %n minute</numerusform><numerusform>Spróbuj ponownie za %n minuty</numerusform><numerusform>Spróbuj ponownie za %n minut</numerusform><numerusform>Spróbuj ponownie za %n minut</numerusform></translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Spróbuj ponownie za 1 minutę</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Spróbuj ponownie za %n minute</numerusform><numerusform>Spróbuj ponownie za %n minuty</numerusform><numerusform>Spróbuj ponownie za %n minut</numerusform><numerusform>Spróbuj ponownie za %n minut</numerusform></translation>
    </message>
</context>
<context>
    <name>AuthWidget</name>
    <message>
        <source>Account</source>
        <translation>Konto</translation>
    </message>
    <message numerus="yes">
        <source>Your password will expire in %n days, please change it timely</source>
        <translation><numerusform>Twoje hasło wygaśnie za %n dzień, proszę zmień je jak najszybciej</numerusform><numerusform>Twoje hasło wygaśnie za %n dni, proszę zmień je jak najszybciej</numerusform><numerusform>Twoje hasło wygaśnie za %n dni, proszę zmień je jak najszybciej</numerusform><numerusform>Twoje hasło wygaśnie za %n dni, proszę zmień je jak najszybciej</numerusform></translation>
    </message>
    <message>
        <source>Password expired, please change</source>
        <translation>Hasło wygasło, proszę zmień je</translation>
    </message>
</context>
<context>
    <name>GreeterWorker</name>
    <message>
        <source>Wrong account</source>
        <translation>Nieprawidłowe konto</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Nieprawidłowe Hasło</translation>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
</context>
<context>
    <name>LockContent</name>
    <message>
        <source>Lock Screen</source>
        <translation>Zablokuj ekran</translation>
    </message>
    <message>
        <source>Failed to lock screen</source>
        <translation>Nie udało się zablokować ekranu</translation>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation>Weryfikacja poprzez odcisk palca przekroczyła czas oczekiwania, prosimy ręcznie wprowadzić hasło.</translation>
    </message>
    <message>
        <source>Failed to match fingerprint</source>
        <translation>Błąd porównania odcisków palcy</translation>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation>Powyżsi użytkownicy są wciąż zalogowani i ich dane mogą zostać utracone w wyniku wyłączenia komputera. Czy na pewno wyłączyć komputer?</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation>Powyżsi użytkownicy są wciąż zalogowani i ich dane mogą zostać utracone w wyniku ponownego uruchomienia komputera. Czy na pewno chcesz ponownie uruchomić komputer?</translation>
    </message>
</context>
<context>
    <name>SessionWidget</name>
    <message>
        <source>You have enabled the high system security level, thus cannot switch to the Wayland mode, please disable the high security level in Security Center and try again.</source>
        <translation>Wysoki poziom został włączony, z tego powodu nie jesteś w stanie przełączyć się na sesję Wayland. Wyłącz wysoki poziom zabezpieczeń w Centrum Bezpieczeństwa, a następnie spróbuj ponownie.</translation>
    </message>
</context>
<context>
    <name>ShutdownWidget</name>
    <message>
        <source>Shut down</source>
        <translation>Wyłącz</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Uruchom ponownie</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Wstrzymaj</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hibernacja</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Zablokuj</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Wyloguj</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>Zmień użytkownika</translation>
    </message>
    <message>
        <source>Switch system</source>
        <translation>System przełączników</translation>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <source>Start system monitor</source>
        <translation>Uruchom monitor systemu</translation>
    </message>
</context>
<context>
    <name>WarningContent</name>
    <message>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>Włączone są programy, które uniemożliwiają wyłączenie komputera, a wymuszenie wyłączenia może spowodować utratę danych.</translation>
    </message>
    <message>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>Aby zamknąć program, kliknij przycisk Anuluj, a następnie zamknij program.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>Włączone są programy, które uniemożliwiają restart komputera, a wymuszenie restartu może spowodować utratę danych.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>Włączone są programy, które uniemożliwiają wstrzymanie komputera, a wymuszenie wstrzymania może spowodować utratę danych.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>Włączone są programy, które uniemożliwiają hibernację komputera, a wymuszenie hibernacji może spowodować utratę danych.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>Włączone są programy, które uniemożliwiają wylogowanie, a wymuszenie wylogowania może spowodować utratę danych.</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Zamknij</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Uruchom ponownie</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Wstrzymaj</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hibernować</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Wyloguj</translation>
    </message>
    <message>
        <source>Are you sure you want to shut down?</source>
        <translation>Czy na pewno chcesz zamknąć?</translation>
    </message>
    <message>
        <source>Are you sure you want to reboot?</source>
        <translation>Czy na pewno chcesz uruchomić ponownie komputer?</translation>
    </message>
    <message>
        <source>Are you sure you want to log out?</source>
        <translation>Czy na pewno chcesz się wylogować?</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Turn on</source>
        <translation>Włącz</translation>
    </message>
    <message>
        <source>Turn off</source>
        <translation>Wyłącz</translation>
    </message>
</context>
</TS>

==> dde-session-shell_5.5.81.orig.tar.xz: dde-session-shell-5.5.81/translations/dde-session-shell_pl.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="pl">
<context>
    <name>AuthFace</name>
    <message>
        <source>Face ID</source>
        <translation>ID Twarzy</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Weryfikacja zakończona pomyślnie</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Weryfikacja nie powiodła się, pozostała tylko jedna próba</translation>
    </message>
    <message>
        <source>Verify your Face ID</source>
        <translation>Zweryfikuj swoje ID Twarzy</translation>
    </message>
    <message>
        <source>Face ID locked, use password please</source>
        <translation>ID Twarzy zablokowane, proszę użyć hasła</translation>
    </message>
    <message>
        <source>Device unavailable!</source>
        <translation>Urządzenie niedostępne!</translation>
    </message>
</context>
<context>
    <name>AuthFingerprint</name>
    <message>
        <source>Verify your fingerprint</source>
        <translation>Zweryfikuj odcisk palca</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Weryfikacja zakończona pomyślnie</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Weryfikacja nie powiodła się, pozostała %n próba</numerusform><numerusform>Weryfikacja nie powiodła się, pozostały %n próby</numerusform><numerusform>Weryfikacja nie powiodła się, pozostało %n prób</numerusform><numerusform>Weryfikacja nie powiodła się, pozostało %n prób</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Weryfikacja nie powiodła się, pozostała tylko jedna próba</translation>
    </message>
    <message>
        <source>Fingerprint locked, use password please</source>
        <translation>Odcisk palca zablokowany, użyj hasła</translation>
    </message>
</context>
<context>
    <name>AuthIris</name>
    <message>
        <source>Iris ID</source>
        <translation>ID Tęczówki</translation>
    </message>
    <message>
        <source>Verification successful</source>
        <translation>Weryfikacja zakończona pomyślnie</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Weryfikacja nie powiodła się, pozostała tylko jedna próba</translation>
    </message>
    <message>
        <source>Verify your Iris ID</source>
        <translation>Zweryfikuj swoje ID Tęczówki</translation>
    </message>
    <message>
        <source>Iris ID locked, use password please</source>
        <translation>ID Tęczówki zablokowane, proszę użyć hasła</translation>
    </message>
</context>
<context>
    <name>AuthPassword</name>
    <message>
        <source>Verification successful</source>
        <translation>Weryfikacja zakończona pomyślnie</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Weryfikacja nie powiodła się, pozostała %n próba</numerusform><numerusform>Weryfikacja nie powiodła się, pozostały %n próby</numerusform><numerusform>Weryfikacja nie powiodła się, pozostało %n prób</numerusform><numerusform>Weryfikacja nie powiodła się, pozostało %n prób</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Weryfikacja nie powiodła się, pozostała tylko jedna próba</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Błędne hasło</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Hasło</translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Spróbuj ponownie za 1 minutę</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Zresetuj hasło</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>Zapomniałeś hasła?</translation>
    </message>
</context>
<context>
    <name>AuthSingle</name>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Spróbuj ponownie za 1 minutę</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation><numerusform>Spróbuj ponownie za %n minutę</numerusform><numerusform>Spróbuj ponownie za %n minuty</numerusform><numerusform>Spróbuj ponownie za %n minut</numerusform><numerusform>Spróbuj ponownie za %n minut</numerusform></translation>
    </message>
    <message>
        <source>Reset Password</source>
        <translation>Zresetuj hasło</translation>
    </message>
    <message>
        <source>Forgot password?</source>
        <translation>Zapomniałeś hasła?</translation>
    </message>
</context>
<context>
    <name>AuthUKey</name>
    <message>
        <source>Verification successful</source>
        <translation>Weryfikacja zakończona pomyślnie</translation>
    </message>
    <message numerus="yes">
        <source>Verification failed, %n chances left</source>
        <translation><numerusform>Weryfikacja nie powiodła się, pozostała %n próba</numerusform><numerusform>Weryfikacja nie powiodła się, pozostały %n próby</numerusform><numerusform>Weryfikacja nie powiodła się, pozostało %n prób</numerusform><numerusform>Weryfikacja nie powiodła się, pozostało %n prób</numerusform></translation>
    </message>
    <message>
        <source>Verification failed, only one chance left</source>
        <translation>Weryfikacja nie powiodła się, pozostała tylko jedna próba</translation>
    </message>
    <message>
        <source>Wrong PIN</source>
        <translation>Błędny PIN</translation>
    </message>
    <message>
        <source>UKey is required</source>
        <translation>UKey jest wymagany</translation>
    </message>
    <message>
        <source>Enter your PIN</source>
        <translation>Wpisz swój PIN</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minute(s) later</source>
        <translation><numerusform>Spróbuj ponownie za %n minutę</numerusform><numerusform>Spróbuj ponownie za %n minuty</numerusform><numerusform>Spróbuj ponownie za %n minut</numerusform><numerusform>Spróbuj ponownie za %n minut</numerusform></translation>
    </message>
    <message>
        <source>Please try again 1 minute later</source>
        <translation>Spróbuj ponownie za 1 minutę</translation>
    </message>
    <message numerus="yes">
        <source>Please try again %n minutes later</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
</context>
<context>
    <name>AuthWidget</name>
    <message>
        <source>Account</source>
        <translation>Konto</translation>
    </message>
    <message numerus="yes">
        <source>Your password will expire in %n days, please change it timely</source>
        <translation type="unfinished"><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
    </message>
    <message>
        <source>Password expired, please change</source>
        <translation>Hasło wygasło, proszę zmień je</translation>
    </message>
</context>
<context>
    <name>GreeterWorker</name>
    <message>
        <source>Wrong account</source>
        <translation>Nieprawidłowe konto</translation>
    </message>
    <message>
        <source>Wrong Password</source>
        <translation>Błędne hasło</translation>
    </message>
</context>
<context>
    <name>InhibitWarnView</name>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
</context>
<context>
    <name>LockContent</name>
    <message>
        <source>Lock Screen</source>
        <translation>Zablokuj ekran</translation>
    </message>
    <message>
        <source>Failed to lock screen</source>
        <translation>Nie udało się zablokować ekranu</translation>
    </message>
</context>
<context>
    <name>LockWorker</name>
    <message>
        <source>Fingerprint verification timed out, please enter your password manually</source>
        <translation>Weryfikacja poprzez odcisk palca przekroczyła czas oczekiwania, prosimy ręcznie wprowadzić hasło.</translation>
    </message>
    <message>
        <source>Failed to match fingerprint</source>
        <translation>Nie udało się dopasować odcisku palca</translation>
    </message>
</context>
<context>
    <name>MultiUsersWarningView</name>
    <message>
        <source>Cancel</source>
        <translation>Anuluj</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to shutdown, are you sure you want to shut down?</source>
        <translation>Powyżsi użytkownicy są wciąż zalogowani i ich dane mogą zostać utracone w wyniku wyłączenia komputera. Czy na pewno wyłączyć komputer?</translation>
    </message>
    <message>
        <source>The above users are still logged in and data will be lost due to reboot, are you sure you want to reboot?</source>
        <translation>Powyżsi użytkownicy są wciąż zalogowani i ich dane mogą zostać utracone w wyniku ponownego uruchomienia komputera. Czy na pewno chcesz ponownie uruchomić komputer?</translation>
    </message>
</context>
<context>
    <name>SessionWidget</name>
    <message>
        <source>You have enabled the high system security level, thus cannot switch to the Wayland mode, please disable the high security level in Security Center and try again.</source>
        <translation>Wysoki poziom został włączony, z tego powodu nie jesteś w stanie przełączyć się na sesję Wayland. Wyłącz wysoki poziom zabezpieczeń w Centrum Bezpieczeństwa, a następnie spróbuj ponownie.</translation>
    </message>
</context>
<context>
    <name>ShutdownWidget</name>
    <message>
        <source>Shut down</source>
        <translation>Wyłącz</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Uruchom ponownie</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Wstrzymaj</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hibernacja</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Zablokuj</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Wyloguj</translation>
    </message>
    <message>
        <source>Switch user</source>
        <translation>Zmień użytkownika</translation>
    </message>
    <message>
        <source>Switch system</source>
        <translation>System przełączników</translation>
    </message>
</context>
<context>
    <name>SystemMonitor</name>
    <message>
        <source>Start system monitor</source>
        <translation>Uruchom monitor systemu</translation>
    </message>
</context>
<context>
    <name>WarningContent</name>
    <message>
        <source>The programs are preventing the computer from shutting down, and forcing shut down may cause data loss.</source>
        <translation>Włączone są programy, które uniemożliwiają wyłączenie komputera, a wymuszenie wyłączenia może spowodować utratę danych.</translation>
    </message>
    <message>
        <source>To close the program, click Cancel, and then close the program.</source>
        <translation>Aby zamknąć program, kliknij przycisk Anuluj, a następnie zamknij program.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from reboot, and forcing reboot may cause data loss.</source>
        <translation>Włączone są programy, które uniemożliwiają restart komputera, a wymuszenie restartu może spowodować utratę danych.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from suspend, and forcing suspend may cause data loss.</source>
        <translation>Włączone są programy, które uniemożliwiają wstrzymanie komputera, a wymuszenie wstrzymania może spowodować utratę danych.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from hibernate, and forcing hibernate may cause data loss.</source>
        <translation>Włączone są programy, które uniemożliwiają hibernację komputera, a wymuszenie hibernacji może spowodować utratę danych.</translation>
    </message>
    <message>
        <source>The programs are preventing the computer from log out, and forcing log out may cause data loss.</source>
        <translation>Włączone są programy, które uniemożliwiają wylogowanie, a wymuszenie wylogowania może spowodować utratę danych.</translation>
    </message>
    <message>
        <source>Shut down</source>
        <translation>Wyłącz</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Uruchom ponownie</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Wstrzymaj</translation>
    </message>
    <message>
        <source>Hibernate</source>
        <translation>Hibernacja</translation>
    </message>
    <message>
        <source>Log out</source>
        <translation>Wyloguj</translation>
    </message>
    <message>
        <source>Are you sure you want to shut down?</source>
        <translation>Czy na pewno chcesz wyłączyć?</translation>
    </message>
    <message>
        <source>Are you sure you want to reboot?</source>
        <translation>Czy na pewno chcesz uruchomić ponownie?</translation>
    </message>
    <message>
        <source>Are you sure you want to log out?</source>
        <translation>Czy na pewno chcesz się wylogować?</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Turn on</source>
        <translation>Włącz</translation>
    </message>
    <message>
        <source>Turn off</source>
        <translation>Wyłącz</translation>
    </message>
</context>
</TS>
